@@ -59,6 +59,8 @@ private Q_SLOTS:
     void receiveRichtextIn();
     void receiveRichMxcUrl();
     void receiveRichPlainUrl();
+
+    void receiveLineSeparator();
 };
 
 #ifdef QUOTIENT_07
@@ -498,5 +500,13 @@ void TextHandlerTest::receiveRichPlainUrl()
     QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText), testOutputStringMxId);
 }
 
+void TextHandlerTest::receiveLineSeparator()
+{
+    auto text = QStringLiteral("foo\u2028bar");
+    TextHandler textHandler;
+    textHandler.setData(text);
+    QCOMPARE(textHandler.handleRecievePlainText(Qt::PlainText, true), QStringLiteral("foo bar"));
+}
+
 QTEST_MAIN(TextHandlerTest)
 #include "texthandlertest.moc"
